/** A path to check its ignore status */
export interface Path {
    /** The absolute path, if any */
    absolutePath?: string;
    /** The relative path, if any */
    relativePath?: string;
    /** If basename of the path, if any */
    basename?: string;
}
/** Ignore Options */
export interface Options {
    /** Absolute paths to ignore */
    ignoreAbsolutePaths?: Array<string | RegExp>;
    /** Relative paths to ignore */
    ignoreRelativePaths?: Array<string | RegExp>;
    /** Basenames to ignore */
    ignoreBasenames?: Array<string | RegExp>;
    /** @deprecated alias for {@link isIgnoredPathCompatibility} that puts absolute paths in {@link ignoreAbsolutePaths}, relative paths in {@link ignoreRelativePaths}, and basenames in {@link ignoreBasenames} */
    ignorePaths?: Array<string | RegExp>;
    /** Ignore basenames that begin with a `.` character */
    ignoreHiddenBasenames?: boolean;
    /** @deprecated aliases {@link Options.ignoreHiddenBasenames} for {@link isIgnoredPathCompatibility} */
    ignoreHiddenFiles?: boolean;
    /** Ignore commonly undesirable basenames: https://github.com/bevry/ignorepatterns */
    ignoreUndesiredBasenames?: boolean;
    /** @deprecated aliases {@link Options.ignoreUndesiredBasenames} for {@link isIgnoredPathCompatibility} */
    ignoreCommonPatterns?: boolean;
    /** Test against each {@link Path} property */
    ignoreCustomPatterns?: RegExp;
    /** Your own ignore handler */
    ignoreCustomCallback?: (path: Path) => boolean | void;
}
/** Tests whether the path should be ignored */
export declare function isIgnoredPath(path: Path, opts?: Options): boolean;
/** Verify options and upgrade deprecations, returns dereferenced copy */
export declare function upgradeOptions(opts: Options): Options;
/** Compatibility wrapper for {@link isIgnoredPath}, supporting path string, verifying path object and options, and handling option deprecations */
export default function isIgnoredPathCompatibility(path: Path | string, opts?: Options): boolean;
//# sourceMappingURL=index.d.ts.map